/**
 * js logic specific to scrolling menu with arrow elements
 */

const moveStartSpeed = 2;
const speedMultiplier = 1.1;
const intervalTime = 50;
const arrowLeftSelector = ".c-scroll-menu__arrow--left";
const arrowRightSelector = ".c-scroll-menu__arrow--right";
const menuListSelector = ".c-scroll-menu__list";

export default {

  /**
   * @method init
   * @description init method, adds event listener for scroll and resize
   * @param rootElement {HTMLElement} an element which will be the scope of the querySelector method
   * @return {void}
   */
  init(rootElement) {
    this.menuList = rootElement.querySelector(menuListSelector);
    this.arrowLeft = rootElement.querySelector(arrowLeftSelector);
    this.arrowRight = rootElement.querySelector(arrowRightSelector);
    this.moveSpeed = moveStartSpeed;
    this.scrollInterval = null;

    // scrolling menu event handlers
    if (this.menuList && this.arrowLeft && this.arrowRight) {

      // left arrow
      this.arrowLeft.addEventListener("mousedown", () => {
        this.cancelInterval();
        this.scrollInterval = setInterval(() => {
          this.scrollMenuLeft();
        }, intervalTime);
      });

      this.arrowLeft.addEventListener("mouseup", () => {
        this.cancelInterval();
      });

      // right arrow
      this.arrowRight.addEventListener("mousedown", () => {
        this.cancelInterval();
        this.scrollInterval = setInterval(() => {
          this.scrollMenuRight();
        }, intervalTime);
      });

      this. arrowRight.addEventListener("mouseup", () => {
        this.cancelInterval();
      });

    }
  },

  /**
   * @method scrollMenuLeft
   * @description the speed increases the longer you hold the button
   * @return {void}
   */
  scrollMenuLeft() {
    this.moveSpeed *= speedMultiplier;
    this.menuList.scrollLeft += this.moveSpeed;
  },

  /**
   * @method scrollMenuRight
   * @description the speed increases the longer you hold the button
   * @return {void}
   */
  scrollMenuRight() {
    this.moveSpeed *= speedMultiplier;
    this.menuList.scrollLeft -= this.moveSpeed;
  },

  /**
   * @method cancelInterval
   * @description cancels interval for scrolling
   * @return {void}
   */
  cancelInterval() {
    this.moveSpeed = moveStartSpeed;
    clearInterval(this.scrollInterval);
  }
};
