/**
 * js logic for sticky header
 */

const _ = require("lodash");
const headerNavSelector = ".c-header-nav";
const headerNavFixedClass = "c-header-nav--fixed";
const sectionHeaderSelector = ".c-header-title--section";
const articleHeaderSelector = ".c-header-title--article";
const sectionUp = "c-header-title--scrolling-up";
const sectionDown = "c-header-title--scrolling-down";
const topThreshold = 60;

let headerNav;
let header;
let pinned = false;
let distance;
let lastScrollTop = 0;

/**
 * @method init
 * @description init method, adds event listener for scroll and resize
 * @return void
 */
export default function init() {
  headerNav = document.querySelector(headerNavSelector);
  header = document.querySelector(sectionHeaderSelector) || document.querySelector(articleHeaderSelector);

  // sticky scrolling logic
  let originalScrollValue = window.pageYOffset;

  window.scrollTo(0, 0);
  headerNav && (distance = headerNav.offsetTop - window.pageYOffset);
  window.scrollTo(0, originalScrollValue);

  // throttled event handlers
  window.addEventListener("scroll", _.throttle(onViewPortChange, 50));
  window.addEventListener("resize", _.throttle(onViewPortChange, 50));

  // run once on initialize
  onViewPortChange();
}

/**
 * @method onViewPortChange
 * @description method checks page scroll offset and applies toggles a class on/off
 * @return void
 */
function onViewPortChange() {
  if (headerNav) {
    const isFixed = headerNav.classList.contains(headerNavFixedClass);

    if (window.pageYOffset >= distance && !isFixed && !pinned) {
      pinned = true;
      headerNav.classList.add(headerNavFixedClass);
    } else if (window.pageYOffset <= distance && pinned) {
      pinned = false;
      headerNav.classList.remove(headerNavFixedClass);
    }
  }

  if (header) {
    const scrollPosition = window.pageYOffset || document.documentElement.scrollTop;
    const withinTopThreshold = scrollPosition < topThreshold;

    if (withinTopThreshold) {

      header.classList.remove(sectionUp);
      header.classList.remove(sectionDown);

    } else if (scrollPosition > lastScrollTop) {

      header.classList.remove(sectionUp);
      header.classList.add(sectionDown);

    } else {

      header.classList.add(sectionUp);
      header.classList.remove(sectionDown);

    }
    lastScrollTop = scrollPosition;
  }
}
